@@ -890,8 +890,8 @@ class Project:
         Imports a collection of SWC files into a project. 
         :param list_of_SWC_paths: list of file paths, one for each SWC file to import
         """
-        l = [pyglass.path(strs.replace('\\','/')) for strs in list_of_SWC_paths]
-        return self.impl.ImportMultipleSWCs(experiment, pyglass.PathList(l))
+        l = [strs.replace('\\','/') for strs in list_of_SWC_paths]
+        return self.impl.ImportSkeletonSWC(experiment, pyglass.StringList(l))
         
     @_closed_project_decorator
     def save_tracings(
